@@ -34,7 +34,7 @@
 #' Note that in 2015 it was determined that the stations with codes ACO, AJU,
 #' INN, MON and MPA would no longer be taken into consideration when computing
 #' the pollution index because they didn't meet the
-#' \href{http://www.aire.cdmx.gob.mx/aire/objetivos-monitoreo-calidad-aire.html}{objectives
+#' \href{http://www.aire.cdmx.gob.mx/objetivos-monitoreo-calidad-aire.html}{objectives
 #' of monitoring air quality}, and are no longer included in the index, even if
 #' they are still part of the SIMAT (Sistema de Monitoreo Atmosférico de la
 #' Ciudad de México). Thus, even if they are located inside a zone, they are not
@@ -44,7 +44,7 @@
 #'   the \emph{America/Mexico_City} timezone (which changes with daylight
 #'   saving time)
 #' @family IMECA functions
-#' @seealso \href{http://www.aire.cdmx.gob.mx/aire/ultima-hora-reporte.php}{Reporte
+#' @seealso \href{http://www.aire.cdmx.gob.mx/ultima-hora-reporte.php}{Reporte
 #'   de calidad del aire}
 #' @export
 #' @importFrom utils URLdecode
@@ -60,7 +60,7 @@
 #' }
 get_latest_imeca <- function() {
   tryCatch({
-    url <- "http://www.aire.cdmx.gob.mx/aire/ultima-hora-reporte.php"
+    url <- "http://www.aire.cdmx.gob.mx/ultima-hora-reporte.php"
 
     result <- GET(url, timeout(120),
                   add_headers("user-agent" =
